from .admin_sidebar import *
from .integration_models import *
from .page_models import *
from .snippet_models import *
from .wagtailsettings_models import *

# cms_models should be improrted inside a specific project,
# if default CMS pages are used: WebPage, ArticleIndexPage, ArticlePage
# from .cms_models import *



from cjkcms.settings import cms_settings
from django.contrib.staticfiles import finders
from django.contrib.staticfiles.storage import staticfiles_storage
from django.template.loader import get_template
from django.test import TestCase
import pytest

# import TemplateDoesNotExist
from django.template import TemplateDoesNotExist

# Test the settings.py file and all templates and static files defined.


class SettingsTests(TestCase):
    def test_brand_logos(self):
        """Check if default brand logos are available."""

        logos = [
            cms_settings.CJKCMS_BRAND_LOGO_LONG,
            cms_settings.CJKCMS_BRAND_LOGO_SQUARE,
        ]

        for logo in logos:
            abs_path = finders.find(logo)
            # self.assertIsNone(abs_path, f"{logo} not found.")
            self.assertTrue(str(abs_path).endswith(logo), f"{logo} not found.")

    @pytest.mark.skip(reason="missing dependencies")
    def test_cardblock_templates(self):
        """Check if all declared template files are accessible."""

        templates = cms_settings.CJKCMS_FRONTEND_TEMPLATES_BLOCKS["cardblock"]

        for tpl in templates:
            # self.assertIsNone(abs_path, f"{logo} not found.")
            try:
                get_template(tpl[0])
            except TemplateDoesNotExist as e:
                self.fail(f"Template not found: {str(e)}")



from cjkcms.tests.test_templatetags import TemplateTagTests
from cjkcms.tests.test_settings import SettingsTests
from cjkcms.tests.test_gravatar import (
    GravatarTests,
    GravatarWithDefaultGravatarUrlTests,
)
from cjkcms.tests.test_articlepages import ArticlePageTests
from cjkcms.tests.test_webpage import WebPageTests
from cjkcms.tests.test_urls import TestFavicon, TestSiteURLs



from wagtail.core.blocks import RawHTMLBlock
from wagtail.core.rich_text import get_text_for_indexing
from django.utils.encoding import force_str

### CMS1 legacy - full file to be removed by 12/2022 ###


class SearchableHTMLBlock(RawHTMLBlock):
    """RawHTMLBlock extended with basic search support"""

    def get_searchable_content(self, value):
        # Strip HTML tags to prevent search backend from indexing them
        source = force_str(value)
        return [get_text_for_indexing(value)]



"""
Default creatable pages used in Cjk CMS, for jump-starting new websites 
without having to create a new page types.
Feel free to replace this file with your own configuration,
in your Wagtail project. Copy+paste and modify as needed.

There are two versions of this file: cms_models and cms_models_legacy.
The legacy version uses StreamField as body field, while the new version
uses CjkcmsStreamField, avoiding issues with migrations. See fields.py for details.
"""
from modelcluster.fields import ParentalKey
from django.utils.translation import gettext_lazy as _
from . import (
    CjkcmsArticlePage,
    CjkcmsArticleIndexPage,
    CjkcmsWebPage,
)
from cjkcms.fields import CjkcmsStreamField
from cjkcms.blocks import LAYOUT_STREAMBLOCKS, CONTENT_STREAMBLOCKS


class ArticlePage(CjkcmsArticlePage):
    """
    Article, suitable for news or blog content.
    """

    class Meta:
        verbose_name = _("Article")
        ordering = ["-first_published_at"]

    # Only allow this page to be created beneath an ArticleIndexPage.
    # parent_page_types = ['website.ArticleIndexPage']

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying CONTENT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        CONTENT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    template = "cjkcms/pages/article_page.html"
    amp_template = "cjkcms/pages/article_page.amp.html"
    search_template = "cjkcms/pages/article_page.search.html"
    search_filterable = True


class ArticleIndexPage(CjkcmsArticleIndexPage):
    """
    Shows a list of article sub-pages.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("Article Landing Page")

    # Override to specify custom index ordering choice/default.
    index_query_pagemodel = "cjkcms.ArticlePage"

    # Only allow ArticlePages beneath this page.
    subpage_types = ["cjkcms.ArticlePage"]

    template = "cjkcms/pages/article_index_page.html"


class WebPage(CjkcmsWebPage):
    """
    General use page with featureful streamfield and SEO attributes.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("Web Page")

    template = "cjkcms/pages/web_page.html"
